==> snortsms-0.14.9.tbz: www/snortsms/outputs/act_action.php <==
<?
/***************************************************************************
 *   Copyright (C) 2005 by J Randolph Smith                                *
 *   snortsms@servangle.net                                                *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

$todaydate = date("F d, Y H:i:s");
$action = $_REQUEST['FRM_action'];
$rows = $_REQUEST['FRM_row'];
$out = "";

// DEBUG
//print "<pre>";
//print_r($_REQUEST);
//print "</pre>\n";




if($action == "Delete")
	{
	if (is_array($rows))
		{
		foreach ( $rows as $id )
			{
			/*** Get the rule ***/
			$sql = "select * FROM TBL_OUTPUTS WHERE id =" . $id;
			$rsRule = $db->query($sql); if (DB::isError($rsRule)) { die ($rsRule->getdebugInfo());}
			$row = $rsRule->fetchRow(DB_FETCHMODE_ASSOC);
			$rsRule->free();
		
			/*** Save a copy to the trash file ***/
			$out .= "output " . $row['name'] . " : " . $row['options'] . "\n";
		
			/*** Delete the rule ***/
			$sql = "DELETE FROM TBL_OUTPUTS WHERE id =" . $id;
			$rsDel = $db->query($sql); if (DB::isError($rsDel)) { die ($rsDel->getdebugInfo());}
	
			}
		}
	else
		{
		//print "<BR>Nothing to delete.<BR>";
		}
	}


	
if ($out != "")
	{
	$handle = fopen($gbl_trashcan, "a");

	fwrite($handle,"###################### Deletion: $todaydate ######################\n");

	fwrite( $handle, $out );
			
	fclose($handle);

	}

	
	
	
// DEBUG
//print "<pre>";
//print_r($_SERVER);
//print "</pre>\n";


header("location:".$_SERVER['HTTP_REFERER']);

?>

==> snortsms-1.0.0.tbz: www/snortsms/outputs/act_action.php <==
<?
/***************************************************************************
 *   Copyright (C) 2005 by J Randolph Smith                                *
 *   snortsms@servangle.net                                                *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

$todaydate = date("F d, Y H:i:s");
$action = $_REQUEST['FRM_action'];
$rows = $_REQUEST['FRM_row'];
$out = "";

// DEBUG
//print "<pre>";
//print_r($_REQUEST);
//print "</pre>\n";




if($action == "Delete")
	{
	if (is_array($rows))
		{
		foreach ( $rows as $id )
			{
			/*** Get the rule ***/
			$sql = "select * FROM TBL_OUTPUTS WHERE id =" . $id;
			$rsRule = $db->query($sql); if (DB::isError($rsRule)) { die ($rsRule->getdebugInfo());}
			$row = $rsRule->fetchRow(DB_FETCHMODE_ASSOC);
			$rsRule->free();
		
			/*** Save a copy to the trash file ***/
			$out .= "output " . $row['name'] . " : " . $row['options'] . "\n";
			
			/*** Remove the output from the assignments table (if assigned to anything) ***/
			$sql = "DELETE FROM TBL_ASSIGNMENTS WHERE type = 'O' AND itemid = " . $id;
			$rsDel = $db->query($sql); if (DB::isError($rsDel)) { Stop ( "[".__FILE__."][".__LINE__."] " . $rsDel->getdebugInfo());}
		
			/*** Delete the rule ***/
			$sql = "DELETE FROM TBL_OUTPUTS WHERE id =" . $id;
			$rsDel = $db->query($sql); if (DB::isError($rsDel)) { die ($rsDel->getdebugInfo());}
	
			}
		}
	else
		{
		//print "<BR>Nothing to delete.<BR>";
		}
	}


	
if ($out != "")
	{
	$handle = fopen($GBL['trashcan'], "a");
	fwrite($handle,"###################### Deletion: $todaydate ######################\n");
	fwrite( $handle, $out );			
	fclose($handle);
	}

	
	
	
// DEBUG
//print "<pre>";
//print_r($_SERVER);
//print "</pre>\n";


header("location:".$_SERVER['HTTP_REFERER']);

?>
